@@ -1,6 +1,8 @@
 import logging
+from unittest.mock import call, patch
+
 import pytest
-from unittest.mock import patch, call
+
 from curvenote.latex.utils import just_log_errors, log_and_raise_errors
 
 
