@@ -1,8 +1,8 @@
 import pytest
-from curvenote.latex.templating.options import (
+from curvenote_template.options import (
     AsideSchemaOption,
-    StringSchemaOption,
     SchemaOptionDefs,
+    StringSchemaOption,
 )
 
 
