@@ -4,15 +4,12 @@ import time
 from collections import namedtuple
 from typing import List, NamedTuple, Optional, Type, Union
 
+import requests
 from pydantic.main import BaseModel
 
 from ...client import Session
 from ...models import Block, BlockFormat, BlockVersion
 from .regex import INLINE_CITATION_BLOCK_REGEX
-import requests
-from collections import namedtuple
-from typing import NamedTuple
-from ...models import BlockVersion
 
 
 class LocalMarker(NamedTuple):
